@@ -8,5 +8,6 @@ fi
 
 sed -i "/^version = .*/c\version = \"$version\"" Cargo.toml
 sed -i "/^Version: .*/c\Version: $version" contrib/rust-cipo.spec
-sed -i "/\.version\\\(\".*/c\.version\(\"$version\"\)" src/main.rs
-rustfmt src/main.rs
\ No newline at end of file
+sed -i "/\.version.*/c\.version\(\"$version\"\)" src/args.rs
+rustfmt src/args.rs
+cargo generate-lockfile
